@@ -84,7 +84,7 @@ class BatchClient:
         type: Literal["MANAGED", "UNMANAGED"],
         serviceRole: str,
         state: Literal["ENABLED", "DISABLED"] = None,
-        computeResources: ComputeResourceTypeDef = None,
+        computeResources: "ComputeResourceTypeDef" = None,
     ) -> CreateComputeEnvironmentResponseTypeDef:
         """
         [Client.create_compute_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/batch.html#Batch.Client.create_compute_environment)
@@ -94,7 +94,7 @@ class BatchClient:
         self,
         jobQueueName: str,
         priority: int,
-        computeEnvironmentOrder: List[ComputeEnvironmentOrderTypeDef],
+        computeEnvironmentOrder: List["ComputeEnvironmentOrderTypeDef"],
         state: Literal["ENABLED", "DISABLED"] = None,
     ) -> CreateJobQueueResponseTypeDef:
         """
@@ -178,10 +178,10 @@ class BatchClient:
         jobDefinitionName: str,
         type: Literal["container", "multinode"],
         parameters: Dict[str, str] = None,
-        containerProperties: ContainerPropertiesTypeDef = None,
-        nodeProperties: NodePropertiesTypeDef = None,
-        retryStrategy: RetryStrategyTypeDef = None,
-        timeout: JobTimeoutTypeDef = None,
+        containerProperties: "ContainerPropertiesTypeDef" = None,
+        nodeProperties: "NodePropertiesTypeDef" = None,
+        retryStrategy: "RetryStrategyTypeDef" = None,
+        timeout: "JobTimeoutTypeDef" = None,
     ) -> RegisterJobDefinitionResponseTypeDef:
         """
         [Client.register_job_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/batch.html#Batch.Client.register_job_definition)
@@ -193,12 +193,12 @@ class BatchClient:
         jobQueue: str,
         jobDefinition: str,
         arrayProperties: ArrayPropertiesTypeDef = None,
-        dependsOn: List[JobDependencyTypeDef] = None,
+        dependsOn: List["JobDependencyTypeDef"] = None,
         parameters: Dict[str, str] = None,
-        containerOverrides: ContainerOverridesTypeDef = None,
+        containerOverrides: "ContainerOverridesTypeDef" = None,
         nodeOverrides: NodeOverridesTypeDef = None,
-        retryStrategy: RetryStrategyTypeDef = None,
-        timeout: JobTimeoutTypeDef = None,
+        retryStrategy: "RetryStrategyTypeDef" = None,
+        timeout: "JobTimeoutTypeDef" = None,
     ) -> SubmitJobResponseTypeDef:
         """
         [Client.submit_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/batch.html#Batch.Client.submit_job)
@@ -225,7 +225,7 @@ class BatchClient:
         jobQueue: str,
         state: Literal["ENABLED", "DISABLED"] = None,
         priority: int = None,
-        computeEnvironmentOrder: List[ComputeEnvironmentOrderTypeDef] = None,
+        computeEnvironmentOrder: List["ComputeEnvironmentOrderTypeDef"] = None,
     ) -> UpdateJobQueueResponseTypeDef:
         """
         [Client.update_job_queue documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/batch.html#Batch.Client.update_job_queue)
