@@ -3,9 +3,9 @@ Main interface for batch service type definitions.
 
 Usage::
 
-    from mypy_boto3.batch.type_defs import ArrayPropertiesTypeDef
+    from mypy_boto3.batch.type_defs import ArrayPropertiesDetailTypeDef
 
-    data: ArrayPropertiesTypeDef = {...}
+    data: ArrayPropertiesDetailTypeDef = {...}
 """
 import sys
 from typing import Dict, List
@@ -21,48 +21,48 @@ else:
 
 
 __all__ = (
-    "ArrayPropertiesTypeDef",
-    "ComputeEnvironmentOrderTypeDef",
-    "LaunchTemplateSpecificationTypeDef",
-    "ComputeResourceTypeDef",
-    "ComputeResourceUpdateTypeDef",
-    "KeyValuePairTypeDef",
-    "ResourceRequirementTypeDef",
-    "ContainerOverridesTypeDef",
-    "DeviceTypeDef",
-    "LinuxParametersTypeDef",
-    "MountPointTypeDef",
-    "UlimitTypeDef",
-    "HostTypeDef",
-    "VolumeTypeDef",
-    "ContainerPropertiesTypeDef",
-    "CreateComputeEnvironmentResponseTypeDef",
-    "CreateJobQueueResponseTypeDef",
-    "ComputeEnvironmentDetailTypeDef",
-    "DescribeComputeEnvironmentsResponseTypeDef",
-    "JobTimeoutTypeDef",
-    "NodeRangePropertyTypeDef",
-    "NodePropertiesTypeDef",
-    "RetryStrategyTypeDef",
-    "JobDefinitionTypeDef",
-    "DescribeJobDefinitionsResponseTypeDef",
-    "JobQueueDetailTypeDef",
-    "DescribeJobQueuesResponseTypeDef",
     "ArrayPropertiesDetailTypeDef",
-    "NetworkInterfaceTypeDef",
+    "ArrayPropertiesSummaryTypeDef",
     "AttemptContainerDetailTypeDef",
     "AttemptDetailTypeDef",
+    "ComputeEnvironmentDetailTypeDef",
+    "ComputeEnvironmentOrderTypeDef",
+    "ComputeResourceTypeDef",
     "ContainerDetailTypeDef",
-    "JobDependencyTypeDef",
-    "NodeDetailsTypeDef",
-    "JobDetailTypeDef",
-    "DescribeJobsResponseTypeDef",
-    "ArrayPropertiesSummaryTypeDef",
+    "ContainerOverridesTypeDef",
+    "ContainerPropertiesTypeDef",
     "ContainerSummaryTypeDef",
-    "NodePropertiesSummaryTypeDef",
+    "DeviceTypeDef",
+    "HostTypeDef",
+    "JobDefinitionTypeDef",
+    "JobDependencyTypeDef",
+    "JobDetailTypeDef",
+    "JobQueueDetailTypeDef",
     "JobSummaryTypeDef",
-    "ListJobsResponseTypeDef",
+    "JobTimeoutTypeDef",
+    "KeyValuePairTypeDef",
+    "LaunchTemplateSpecificationTypeDef",
+    "LinuxParametersTypeDef",
+    "MountPointTypeDef",
+    "NetworkInterfaceTypeDef",
+    "NodeDetailsTypeDef",
+    "NodePropertiesSummaryTypeDef",
+    "NodePropertiesTypeDef",
     "NodePropertyOverrideTypeDef",
+    "NodeRangePropertyTypeDef",
+    "ResourceRequirementTypeDef",
+    "RetryStrategyTypeDef",
+    "UlimitTypeDef",
+    "VolumeTypeDef",
+    "ArrayPropertiesTypeDef",
+    "ComputeResourceUpdateTypeDef",
+    "CreateComputeEnvironmentResponseTypeDef",
+    "CreateJobQueueResponseTypeDef",
+    "DescribeComputeEnvironmentsResponseTypeDef",
+    "DescribeJobDefinitionsResponseTypeDef",
+    "DescribeJobQueuesResponseTypeDef",
+    "DescribeJobsResponseTypeDef",
+    "ListJobsResponseTypeDef",
     "NodeOverridesTypeDef",
     "PaginatorConfigTypeDef",
     "RegisterJobDefinitionResponseTypeDef",
@@ -71,18 +71,68 @@ __all__ = (
     "UpdateJobQueueResponseTypeDef",
 )
 
-ArrayPropertiesTypeDef = TypedDict("ArrayPropertiesTypeDef", {"size": int}, total=False)
+ArrayPropertiesDetailTypeDef = TypedDict(
+    "ArrayPropertiesDetailTypeDef",
+    {"statusSummary": Dict[str, int], "size": int, "index": int},
+    total=False,
+)
+
+ArrayPropertiesSummaryTypeDef = TypedDict(
+    "ArrayPropertiesSummaryTypeDef", {"size": int, "index": int}, total=False
+)
+
+AttemptContainerDetailTypeDef = TypedDict(
+    "AttemptContainerDetailTypeDef",
+    {
+        "containerInstanceArn": str,
+        "taskArn": str,
+        "exitCode": int,
+        "reason": str,
+        "logStreamName": str,
+        "networkInterfaces": List["NetworkInterfaceTypeDef"],
+    },
+    total=False,
+)
+
+AttemptDetailTypeDef = TypedDict(
+    "AttemptDetailTypeDef",
+    {
+        "container": "AttemptContainerDetailTypeDef",
+        "startedAt": int,
+        "stoppedAt": int,
+        "statusReason": str,
+    },
+    total=False,
+)
+
+_RequiredComputeEnvironmentDetailTypeDef = TypedDict(
+    "_RequiredComputeEnvironmentDetailTypeDef",
+    {"computeEnvironmentName": str, "computeEnvironmentArn": str, "ecsClusterArn": str},
+)
+_OptionalComputeEnvironmentDetailTypeDef = TypedDict(
+    "_OptionalComputeEnvironmentDetailTypeDef",
+    {
+        "type": Literal["MANAGED", "UNMANAGED"],
+        "state": Literal["ENABLED", "DISABLED"],
+        "status": Literal["CREATING", "UPDATING", "DELETING", "DELETED", "VALID", "INVALID"],
+        "statusReason": str,
+        "computeResources": "ComputeResourceTypeDef",
+        "serviceRole": str,
+    },
+    total=False,
+)
+
+
+class ComputeEnvironmentDetailTypeDef(
+    _RequiredComputeEnvironmentDetailTypeDef, _OptionalComputeEnvironmentDetailTypeDef
+):
+    pass
+
 
 ComputeEnvironmentOrderTypeDef = TypedDict(
     "ComputeEnvironmentOrderTypeDef", {"order": int, "computeEnvironment": str}
 )
 
-LaunchTemplateSpecificationTypeDef = TypedDict(
-    "LaunchTemplateSpecificationTypeDef",
-    {"launchTemplateId": str, "launchTemplateName": str, "version": str},
-    total=False,
-)
-
 _RequiredComputeResourceTypeDef = TypedDict(
     "_RequiredComputeResourceTypeDef",
     {
@@ -108,7 +158,7 @@ _OptionalComputeResourceTypeDef = TypedDict(
         "placementGroup": str,
         "bidPercentage": int,
         "spotIamFleetRole": str,
-        "launchTemplate": LaunchTemplateSpecificationTypeDef,
+        "launchTemplate": "LaunchTemplateSpecificationTypeDef",
     },
     total=False,
 )
@@ -118,18 +168,34 @@ class ComputeResourceTypeDef(_RequiredComputeResourceTypeDef, _OptionalComputeRe
     pass
 
 
-ComputeResourceUpdateTypeDef = TypedDict(
-    "ComputeResourceUpdateTypeDef",
-    {"minvCpus": int, "maxvCpus": int, "desiredvCpus": int},
+ContainerDetailTypeDef = TypedDict(
+    "ContainerDetailTypeDef",
+    {
+        "image": str,
+        "vcpus": int,
+        "memory": int,
+        "command": List[str],
+        "jobRoleArn": str,
+        "volumes": List["VolumeTypeDef"],
+        "environment": List["KeyValuePairTypeDef"],
+        "mountPoints": List["MountPointTypeDef"],
+        "readonlyRootFilesystem": bool,
+        "ulimits": List["UlimitTypeDef"],
+        "privileged": bool,
+        "user": str,
+        "exitCode": int,
+        "reason": str,
+        "containerInstanceArn": str,
+        "taskArn": str,
+        "logStreamName": str,
+        "instanceType": str,
+        "networkInterfaces": List["NetworkInterfaceTypeDef"],
+        "resourceRequirements": List["ResourceRequirementTypeDef"],
+        "linuxParameters": "LinuxParametersTypeDef",
+    },
     total=False,
 )
 
-KeyValuePairTypeDef = TypedDict("KeyValuePairTypeDef", {"name": str, "value": str}, total=False)
-
-ResourceRequirementTypeDef = TypedDict(
-    "ResourceRequirementTypeDef", {"value": str, "type": Literal["GPU"]}
-)
-
 ContainerOverridesTypeDef = TypedDict(
     "ContainerOverridesTypeDef",
     {
@@ -137,12 +203,38 @@ ContainerOverridesTypeDef = TypedDict(
         "memory": int,
         "command": List[str],
         "instanceType": str,
-        "environment": List[KeyValuePairTypeDef],
-        "resourceRequirements": List[ResourceRequirementTypeDef],
+        "environment": List["KeyValuePairTypeDef"],
+        "resourceRequirements": List["ResourceRequirementTypeDef"],
     },
     total=False,
 )
 
+ContainerPropertiesTypeDef = TypedDict(
+    "ContainerPropertiesTypeDef",
+    {
+        "image": str,
+        "vcpus": int,
+        "memory": int,
+        "command": List[str],
+        "jobRoleArn": str,
+        "volumes": List["VolumeTypeDef"],
+        "environment": List["KeyValuePairTypeDef"],
+        "mountPoints": List["MountPointTypeDef"],
+        "readonlyRootFilesystem": bool,
+        "privileged": bool,
+        "ulimits": List["UlimitTypeDef"],
+        "user": str,
+        "instanceType": str,
+        "resourceRequirements": List["ResourceRequirementTypeDef"],
+        "linuxParameters": "LinuxParametersTypeDef",
+    },
+    total=False,
+)
+
+ContainerSummaryTypeDef = TypedDict(
+    "ContainerSummaryTypeDef", {"exitCode": int, "reason": str}, total=False
+)
+
 _RequiredDeviceTypeDef = TypedDict("_RequiredDeviceTypeDef", {"hostPath": str})
 _OptionalDeviceTypeDef = TypedDict(
     "_OptionalDeviceTypeDef",
@@ -155,105 +247,8 @@ class DeviceTypeDef(_RequiredDeviceTypeDef, _OptionalDeviceTypeDef):
     pass
 
 
-LinuxParametersTypeDef = TypedDict(
-    "LinuxParametersTypeDef", {"devices": List[DeviceTypeDef]}, total=False
-)
-
-MountPointTypeDef = TypedDict(
-    "MountPointTypeDef", {"containerPath": str, "readOnly": bool, "sourceVolume": str}, total=False
-)
-
-UlimitTypeDef = TypedDict("UlimitTypeDef", {"hardLimit": int, "name": str, "softLimit": int})
-
 HostTypeDef = TypedDict("HostTypeDef", {"sourcePath": str}, total=False)
 
-VolumeTypeDef = TypedDict("VolumeTypeDef", {"host": HostTypeDef, "name": str}, total=False)
-
-ContainerPropertiesTypeDef = TypedDict(
-    "ContainerPropertiesTypeDef",
-    {
-        "image": str,
-        "vcpus": int,
-        "memory": int,
-        "command": List[str],
-        "jobRoleArn": str,
-        "volumes": List[VolumeTypeDef],
-        "environment": List[KeyValuePairTypeDef],
-        "mountPoints": List[MountPointTypeDef],
-        "readonlyRootFilesystem": bool,
-        "privileged": bool,
-        "ulimits": List[UlimitTypeDef],
-        "user": str,
-        "instanceType": str,
-        "resourceRequirements": List[ResourceRequirementTypeDef],
-        "linuxParameters": LinuxParametersTypeDef,
-    },
-    total=False,
-)
-
-CreateComputeEnvironmentResponseTypeDef = TypedDict(
-    "CreateComputeEnvironmentResponseTypeDef",
-    {"computeEnvironmentName": str, "computeEnvironmentArn": str},
-    total=False,
-)
-
-CreateJobQueueResponseTypeDef = TypedDict(
-    "CreateJobQueueResponseTypeDef", {"jobQueueName": str, "jobQueueArn": str}
-)
-
-_RequiredComputeEnvironmentDetailTypeDef = TypedDict(
-    "_RequiredComputeEnvironmentDetailTypeDef",
-    {"computeEnvironmentName": str, "computeEnvironmentArn": str, "ecsClusterArn": str},
-)
-_OptionalComputeEnvironmentDetailTypeDef = TypedDict(
-    "_OptionalComputeEnvironmentDetailTypeDef",
-    {
-        "type": Literal["MANAGED", "UNMANAGED"],
-        "state": Literal["ENABLED", "DISABLED"],
-        "status": Literal["CREATING", "UPDATING", "DELETING", "DELETED", "VALID", "INVALID"],
-        "statusReason": str,
-        "computeResources": ComputeResourceTypeDef,
-        "serviceRole": str,
-    },
-    total=False,
-)
-
-
-class ComputeEnvironmentDetailTypeDef(
-    _RequiredComputeEnvironmentDetailTypeDef, _OptionalComputeEnvironmentDetailTypeDef
-):
-    pass
-
-
-DescribeComputeEnvironmentsResponseTypeDef = TypedDict(
-    "DescribeComputeEnvironmentsResponseTypeDef",
-    {"computeEnvironments": List[ComputeEnvironmentDetailTypeDef], "nextToken": str},
-    total=False,
-)
-
-JobTimeoutTypeDef = TypedDict("JobTimeoutTypeDef", {"attemptDurationSeconds": int}, total=False)
-
-_RequiredNodeRangePropertyTypeDef = TypedDict(
-    "_RequiredNodeRangePropertyTypeDef", {"targetNodes": str}
-)
-_OptionalNodeRangePropertyTypeDef = TypedDict(
-    "_OptionalNodeRangePropertyTypeDef", {"container": ContainerPropertiesTypeDef}, total=False
-)
-
-
-class NodeRangePropertyTypeDef(
-    _RequiredNodeRangePropertyTypeDef, _OptionalNodeRangePropertyTypeDef
-):
-    pass
-
-
-NodePropertiesTypeDef = TypedDict(
-    "NodePropertiesTypeDef",
-    {"numNodes": int, "mainNode": int, "nodeRangeProperties": List[NodeRangePropertyTypeDef]},
-)
-
-RetryStrategyTypeDef = TypedDict("RetryStrategyTypeDef", {"attempts": int}, total=False)
-
 _RequiredJobDefinitionTypeDef = TypedDict(
     "_RequiredJobDefinitionTypeDef",
     {"jobDefinitionName": str, "jobDefinitionArn": str, "revision": int, "type": str},
@@ -263,10 +258,10 @@ _OptionalJobDefinitionTypeDef = TypedDict(
     {
         "status": str,
         "parameters": Dict[str, str],
-        "retryStrategy": RetryStrategyTypeDef,
-        "containerProperties": ContainerPropertiesTypeDef,
-        "timeout": JobTimeoutTypeDef,
-        "nodeProperties": NodePropertiesTypeDef,
+        "retryStrategy": "RetryStrategyTypeDef",
+        "containerProperties": "ContainerPropertiesTypeDef",
+        "timeout": "JobTimeoutTypeDef",
+        "nodeProperties": "NodePropertiesTypeDef",
     },
     total=False,
 )
@@ -276,114 +271,10 @@ class JobDefinitionTypeDef(_RequiredJobDefinitionTypeDef, _OptionalJobDefinition
     pass
 
 
-DescribeJobDefinitionsResponseTypeDef = TypedDict(
-    "DescribeJobDefinitionsResponseTypeDef",
-    {"jobDefinitions": List[JobDefinitionTypeDef], "nextToken": str},
-    total=False,
-)
-
-_RequiredJobQueueDetailTypeDef = TypedDict(
-    "_RequiredJobQueueDetailTypeDef",
-    {
-        "jobQueueName": str,
-        "jobQueueArn": str,
-        "state": Literal["ENABLED", "DISABLED"],
-        "priority": int,
-        "computeEnvironmentOrder": List[ComputeEnvironmentOrderTypeDef],
-    },
-)
-_OptionalJobQueueDetailTypeDef = TypedDict(
-    "_OptionalJobQueueDetailTypeDef",
-    {
-        "status": Literal["CREATING", "UPDATING", "DELETING", "DELETED", "VALID", "INVALID"],
-        "statusReason": str,
-    },
-    total=False,
-)
-
-
-class JobQueueDetailTypeDef(_RequiredJobQueueDetailTypeDef, _OptionalJobQueueDetailTypeDef):
-    pass
-
-
-DescribeJobQueuesResponseTypeDef = TypedDict(
-    "DescribeJobQueuesResponseTypeDef",
-    {"jobQueues": List[JobQueueDetailTypeDef], "nextToken": str},
-    total=False,
-)
-
-ArrayPropertiesDetailTypeDef = TypedDict(
-    "ArrayPropertiesDetailTypeDef",
-    {"statusSummary": Dict[str, int], "size": int, "index": int},
-    total=False,
-)
-
-NetworkInterfaceTypeDef = TypedDict(
-    "NetworkInterfaceTypeDef",
-    {"attachmentId": str, "ipv6Address": str, "privateIpv4Address": str},
-    total=False,
-)
-
-AttemptContainerDetailTypeDef = TypedDict(
-    "AttemptContainerDetailTypeDef",
-    {
-        "containerInstanceArn": str,
-        "taskArn": str,
-        "exitCode": int,
-        "reason": str,
-        "logStreamName": str,
-        "networkInterfaces": List[NetworkInterfaceTypeDef],
-    },
-    total=False,
-)
-
-AttemptDetailTypeDef = TypedDict(
-    "AttemptDetailTypeDef",
-    {
-        "container": AttemptContainerDetailTypeDef,
-        "startedAt": int,
-        "stoppedAt": int,
-        "statusReason": str,
-    },
-    total=False,
-)
-
-ContainerDetailTypeDef = TypedDict(
-    "ContainerDetailTypeDef",
-    {
-        "image": str,
-        "vcpus": int,
-        "memory": int,
-        "command": List[str],
-        "jobRoleArn": str,
-        "volumes": List[VolumeTypeDef],
-        "environment": List[KeyValuePairTypeDef],
-        "mountPoints": List[MountPointTypeDef],
-        "readonlyRootFilesystem": bool,
-        "ulimits": List[UlimitTypeDef],
-        "privileged": bool,
-        "user": str,
-        "exitCode": int,
-        "reason": str,
-        "containerInstanceArn": str,
-        "taskArn": str,
-        "logStreamName": str,
-        "instanceType": str,
-        "networkInterfaces": List[NetworkInterfaceTypeDef],
-        "resourceRequirements": List[ResourceRequirementTypeDef],
-        "linuxParameters": LinuxParametersTypeDef,
-    },
-    total=False,
-)
-
 JobDependencyTypeDef = TypedDict(
     "JobDependencyTypeDef", {"jobId": str, "type": Literal["N_TO_N", "SEQUENTIAL"]}, total=False
 )
 
-NodeDetailsTypeDef = TypedDict(
-    "NodeDetailsTypeDef", {"nodeIndex": int, "isMainNode": bool}, total=False
-)
-
 _RequiredJobDetailTypeDef = TypedDict(
     "_RequiredJobDetailTypeDef",
     {
@@ -400,18 +291,18 @@ _RequiredJobDetailTypeDef = TypedDict(
 _OptionalJobDetailTypeDef = TypedDict(
     "_OptionalJobDetailTypeDef",
     {
-        "attempts": List[AttemptDetailTypeDef],
+        "attempts": List["AttemptDetailTypeDef"],
         "statusReason": str,
         "createdAt": int,
-        "retryStrategy": RetryStrategyTypeDef,
+        "retryStrategy": "RetryStrategyTypeDef",
         "stoppedAt": int,
-        "dependsOn": List[JobDependencyTypeDef],
+        "dependsOn": List["JobDependencyTypeDef"],
         "parameters": Dict[str, str],
-        "container": ContainerDetailTypeDef,
-        "nodeDetails": NodeDetailsTypeDef,
-        "nodeProperties": NodePropertiesTypeDef,
-        "arrayProperties": ArrayPropertiesDetailTypeDef,
-        "timeout": JobTimeoutTypeDef,
+        "container": "ContainerDetailTypeDef",
+        "nodeDetails": "NodeDetailsTypeDef",
+        "nodeProperties": "NodePropertiesTypeDef",
+        "arrayProperties": "ArrayPropertiesDetailTypeDef",
+        "timeout": "JobTimeoutTypeDef",
     },
     total=False,
 )
@@ -421,24 +312,30 @@ class JobDetailTypeDef(_RequiredJobDetailTypeDef, _OptionalJobDetailTypeDef):
     pass
 
 
-DescribeJobsResponseTypeDef = TypedDict(
-    "DescribeJobsResponseTypeDef", {"jobs": List[JobDetailTypeDef]}, total=False
+_RequiredJobQueueDetailTypeDef = TypedDict(
+    "_RequiredJobQueueDetailTypeDef",
+    {
+        "jobQueueName": str,
+        "jobQueueArn": str,
+        "state": Literal["ENABLED", "DISABLED"],
+        "priority": int,
+        "computeEnvironmentOrder": List["ComputeEnvironmentOrderTypeDef"],
+    },
 )
-
-ArrayPropertiesSummaryTypeDef = TypedDict(
-    "ArrayPropertiesSummaryTypeDef", {"size": int, "index": int}, total=False
-)
-
-ContainerSummaryTypeDef = TypedDict(
-    "ContainerSummaryTypeDef", {"exitCode": int, "reason": str}, total=False
-)
-
-NodePropertiesSummaryTypeDef = TypedDict(
-    "NodePropertiesSummaryTypeDef",
-    {"isMainNode": bool, "numNodes": int, "nodeIndex": int},
+_OptionalJobQueueDetailTypeDef = TypedDict(
+    "_OptionalJobQueueDetailTypeDef",
+    {
+        "status": Literal["CREATING", "UPDATING", "DELETING", "DELETED", "VALID", "INVALID"],
+        "statusReason": str,
+    },
     total=False,
 )
 
+
+class JobQueueDetailTypeDef(_RequiredJobQueueDetailTypeDef, _OptionalJobQueueDetailTypeDef):
+    pass
+
+
 _RequiredJobSummaryTypeDef = TypedDict("_RequiredJobSummaryTypeDef", {"jobId": str, "jobName": str})
 _OptionalJobSummaryTypeDef = TypedDict(
     "_OptionalJobSummaryTypeDef",
@@ -450,9 +347,9 @@ _OptionalJobSummaryTypeDef = TypedDict(
         "statusReason": str,
         "startedAt": int,
         "stoppedAt": int,
-        "container": ContainerSummaryTypeDef,
-        "arrayProperties": ArrayPropertiesSummaryTypeDef,
-        "nodeProperties": NodePropertiesSummaryTypeDef,
+        "container": "ContainerSummaryTypeDef",
+        "arrayProperties": "ArrayPropertiesSummaryTypeDef",
+        "nodeProperties": "NodePropertiesSummaryTypeDef",
     },
     total=False,
 )
@@ -462,24 +359,51 @@ class JobSummaryTypeDef(_RequiredJobSummaryTypeDef, _OptionalJobSummaryTypeDef):
     pass
 
 
-_RequiredListJobsResponseTypeDef = TypedDict(
-    "_RequiredListJobsResponseTypeDef", {"jobSummaryList": List[JobSummaryTypeDef]}
-)
-_OptionalListJobsResponseTypeDef = TypedDict(
-    "_OptionalListJobsResponseTypeDef", {"nextToken": str}, total=False
+JobTimeoutTypeDef = TypedDict("JobTimeoutTypeDef", {"attemptDurationSeconds": int}, total=False)
+
+KeyValuePairTypeDef = TypedDict("KeyValuePairTypeDef", {"name": str, "value": str}, total=False)
+
+LaunchTemplateSpecificationTypeDef = TypedDict(
+    "LaunchTemplateSpecificationTypeDef",
+    {"launchTemplateId": str, "launchTemplateName": str, "version": str},
+    total=False,
 )
 
+LinuxParametersTypeDef = TypedDict(
+    "LinuxParametersTypeDef", {"devices": List["DeviceTypeDef"]}, total=False
+)
 
-class ListJobsResponseTypeDef(_RequiredListJobsResponseTypeDef, _OptionalListJobsResponseTypeDef):
-    pass
+MountPointTypeDef = TypedDict(
+    "MountPointTypeDef", {"containerPath": str, "readOnly": bool, "sourceVolume": str}, total=False
+)
 
+NetworkInterfaceTypeDef = TypedDict(
+    "NetworkInterfaceTypeDef",
+    {"attachmentId": str, "ipv6Address": str, "privateIpv4Address": str},
+    total=False,
+)
+
+NodeDetailsTypeDef = TypedDict(
+    "NodeDetailsTypeDef", {"nodeIndex": int, "isMainNode": bool}, total=False
+)
+
+NodePropertiesSummaryTypeDef = TypedDict(
+    "NodePropertiesSummaryTypeDef",
+    {"isMainNode": bool, "numNodes": int, "nodeIndex": int},
+    total=False,
+)
+
+NodePropertiesTypeDef = TypedDict(
+    "NodePropertiesTypeDef",
+    {"numNodes": int, "mainNode": int, "nodeRangeProperties": List["NodeRangePropertyTypeDef"]},
+)
 
 _RequiredNodePropertyOverrideTypeDef = TypedDict(
     "_RequiredNodePropertyOverrideTypeDef", {"targetNodes": str}
 )
 _OptionalNodePropertyOverrideTypeDef = TypedDict(
     "_OptionalNodePropertyOverrideTypeDef",
-    {"containerOverrides": ContainerOverridesTypeDef},
+    {"containerOverrides": "ContainerOverridesTypeDef"},
     total=False,
 )
 
@@ -490,9 +414,85 @@ class NodePropertyOverrideTypeDef(
     pass
 
 
+_RequiredNodeRangePropertyTypeDef = TypedDict(
+    "_RequiredNodeRangePropertyTypeDef", {"targetNodes": str}
+)
+_OptionalNodeRangePropertyTypeDef = TypedDict(
+    "_OptionalNodeRangePropertyTypeDef", {"container": "ContainerPropertiesTypeDef"}, total=False
+)
+
+
+class NodeRangePropertyTypeDef(
+    _RequiredNodeRangePropertyTypeDef, _OptionalNodeRangePropertyTypeDef
+):
+    pass
+
+
+ResourceRequirementTypeDef = TypedDict(
+    "ResourceRequirementTypeDef", {"value": str, "type": Literal["GPU"]}
+)
+
+RetryStrategyTypeDef = TypedDict("RetryStrategyTypeDef", {"attempts": int}, total=False)
+
+UlimitTypeDef = TypedDict("UlimitTypeDef", {"hardLimit": int, "name": str, "softLimit": int})
+
+VolumeTypeDef = TypedDict("VolumeTypeDef", {"host": "HostTypeDef", "name": str}, total=False)
+
+ArrayPropertiesTypeDef = TypedDict("ArrayPropertiesTypeDef", {"size": int}, total=False)
+
+ComputeResourceUpdateTypeDef = TypedDict(
+    "ComputeResourceUpdateTypeDef",
+    {"minvCpus": int, "maxvCpus": int, "desiredvCpus": int},
+    total=False,
+)
+
+CreateComputeEnvironmentResponseTypeDef = TypedDict(
+    "CreateComputeEnvironmentResponseTypeDef",
+    {"computeEnvironmentName": str, "computeEnvironmentArn": str},
+    total=False,
+)
+
+CreateJobQueueResponseTypeDef = TypedDict(
+    "CreateJobQueueResponseTypeDef", {"jobQueueName": str, "jobQueueArn": str}
+)
+
+DescribeComputeEnvironmentsResponseTypeDef = TypedDict(
+    "DescribeComputeEnvironmentsResponseTypeDef",
+    {"computeEnvironments": List["ComputeEnvironmentDetailTypeDef"], "nextToken": str},
+    total=False,
+)
+
+DescribeJobDefinitionsResponseTypeDef = TypedDict(
+    "DescribeJobDefinitionsResponseTypeDef",
+    {"jobDefinitions": List["JobDefinitionTypeDef"], "nextToken": str},
+    total=False,
+)
+
+DescribeJobQueuesResponseTypeDef = TypedDict(
+    "DescribeJobQueuesResponseTypeDef",
+    {"jobQueues": List["JobQueueDetailTypeDef"], "nextToken": str},
+    total=False,
+)
+
+DescribeJobsResponseTypeDef = TypedDict(
+    "DescribeJobsResponseTypeDef", {"jobs": List["JobDetailTypeDef"]}, total=False
+)
+
+_RequiredListJobsResponseTypeDef = TypedDict(
+    "_RequiredListJobsResponseTypeDef", {"jobSummaryList": List["JobSummaryTypeDef"]}
+)
+_OptionalListJobsResponseTypeDef = TypedDict(
+    "_OptionalListJobsResponseTypeDef", {"nextToken": str}, total=False
+)
+
+
+class ListJobsResponseTypeDef(_RequiredListJobsResponseTypeDef, _OptionalListJobsResponseTypeDef):
+    pass
+
+
 NodeOverridesTypeDef = TypedDict(
     "NodeOverridesTypeDef",
-    {"numNodes": int, "nodePropertyOverrides": List[NodePropertyOverrideTypeDef]},
+    {"numNodes": int, "nodePropertyOverrides": List["NodePropertyOverrideTypeDef"]},
     total=False,
 )
 
